<?php

namespace Sarfraz\Sarfraz\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Sarfraz\Sarfraz\Http\Requests\CategoryAdminRequest;
use Sarfraz\Sarfraz\Interfaces\CategoryRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class CategoryAdminController extends AdminController
{
    /**
     * Initialize category controller.
     *
     * @param type CategoryRepositoryInterface $category
     *
     * @return type
     */
    public function __construct(CategoryRepositoryInterface $category)
    {
        $this->model = $category;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(CategoryAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('sarfraz.category.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('sarfraz::category.names').' :: ');

        return $this->theme->of('sarfraz::admin.category.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(CategoryAdminRequest $request, $id)
    {
        $category = $this->model->find($id);

        if (empty($category)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('sarfraz::admin.category.new');
        }

        if ($request->wantsJson()) {
            return $category;
        }

        Former::populate($category);

        return view('sarfraz::admin.category.show', compact('category'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CategoryAdminRequest $request)
    {
        $category = $this->model->findOrNew(0);
        Former::populate($category);

        return view('sarfraz::admin.category.create', compact('category'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CategoryAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $category = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('sarfraz::category.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(CategoryAdminRequest $request, $id)
    {
        $category = $this->model->find($id);

        Former::populate($category);

        return view('sarfraz::admin.category.edit', compact('category'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(CategoryAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $category = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('sarfraz::category.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(CategoryAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('sarfraz::category.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
